Personal assistant bot
This bot can help to manage your contacts and notes.
If you are a fan of the command line, if MS DOS it's your first love, this bot will melt your heart.

Using this bot:
- you will not miss your spouse's birthday;
- you will not forget a shopping list;
- ... and more (to see all available actions, please, use the "help" command after installation and running the Bot).

The Bot is compatible with Windows and MacOS.
Tested on python 3.10, probably not compatible with previous versions.

Installation
Download package, unpack it and use next command to install it from unpacked folder:
